@@ -134,26 +134,19 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrAlternateLangPanel * panel)
 static void
 open_file (GtkWidget *dialog, GtrAlternateLangPanel *panel)
 {
-  GFile *file;
-  gchar *po_file;
+  g_autoptr (GFile) file = NULL;
   GtrMsg *current;
   GtrPo *current_po;
   GList *l;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
-  //po_file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
   file = gtk_file_chooser_get_file (chooser);
-  //filename = g_file_get_path(file);
-  //file = g_file_new_for_path (po_file);
-  g_free (po_file);
 
   if (panel->priv->po != NULL)
     g_object_unref (panel->priv->po);
   panel->priv->po = gtr_po_new ();
   gtr_po_parse (panel->priv->po, file, &error);
 
-  g_object_unref (file);
-
   if (error != NULL)
     {
       GtkWidget *erdialog;
@@ -167,7 +160,6 @@ open_file (GtkWidget *dialog, GtrAlternateLangPanel *panel)
                                          "%s", error->message);
       g_signal_connect (erdialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
       gtk_window_present (GTK_WINDOW (erdialog));
-      g_error_free (error);
       return;
     }
 
