@@ -94,8 +94,8 @@ gtr_dict_panel_create_warning_dialog (const gchar * primary,
   if (secondary)
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
                                               "%s", secondary);
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_widget_destroy (dialog);
+  g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+  gtk_window_present (GTK_WINDOW (dialog));
 }
 
 static void
@@ -523,7 +523,7 @@ gtr_dict_panel_init (GtrDictPanel * panel)
   g_signal_connect (panel->priv->defbox, "link-clicked",
                     G_CALLBACK (gtr_dict_panel_link_clicked), panel);
 
-  gtk_container_add (GTK_CONTAINER (vbox), panel->priv->defbox);
+  gtk_box_append (G_BOX (vbox), panel->priv->defbox);
   gtk_widget_show (panel->priv->defbox);
 
   /* Sidebar */
