@@ -281,7 +281,11 @@ preferences_activated (GSimpleAction *action,
                        gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  gtr_show_preferences_dialog (get_active_window (app));
+  GtrWindow *window;
+
+  window = get_active_window (app);
+  if (adw_application_window_get_visible_dialog (ADW_APPLICATION_WINDOW (window)) == NULL)
+    gtr_show_preferences_dialog (window);
 }
 
 static void
@@ -376,6 +380,11 @@ dl_activated (GSimpleAction *action,
   GtrApplication *app = GTR_APPLICATION (user_data);
 
   GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
+  if (active_tab == NULL) {
+    gtr_window_show_dlteams (get_active_window (app));
+    return;
+  }
+
   GtrPoState state = gtr_po_get_state (gtr_tab_get_po (active_tab));
 
   if (state == GTR_PO_STATE_MODIFIED)
@@ -652,10 +661,10 @@ GtrWindow *
 gtr_application_create_window (GtrApplication *app)
 {
   GtrWindow *window;
-  GdkToplevelState state;
   gint w, h;
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   GtkWindowGroup *group;
+  gboolean is_maximized;
 
   group = gtk_window_group_new ();
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
@@ -664,19 +673,16 @@ gtr_application_create_window (GtrApplication *app)
   gtk_window_group_add_window (group, GTK_WINDOW (window));
   g_object_unref (group);
 
-  state = g_settings_get_int (priv->window_settings,
-                              GTR_SETTINGS_WINDOW_STATE);
-
   g_settings_get (priv->window_settings,
                   GTR_SETTINGS_WINDOW_SIZE,
                   "(ii)", &w, &h);
 
   gtk_window_set_default_size (GTK_WINDOW (window), w, h);
 
-  if ((state & GDK_TOPLEVEL_STATE_MAXIMIZED) != 0)
+  is_maximized = g_settings_get_boolean (priv->window_settings,
+                                         GTR_SETTINGS_WINDOW_MAXIMIZED);
+  if (is_maximized)
     gtk_window_maximize (GTK_WINDOW (window));
-  else
-    gtk_window_unmaximize (GTK_WINDOW (window));
 
   g_signal_connect (window, "close-request",
                     G_CALLBACK (on_window_delete_event_cb), app);
