@@ -105,12 +105,8 @@ GQuark gtr_po_error_quark (void);
 
      void gtr_po_set_location (GtrPo * po, GFile * location);
 
-     gboolean gtr_po_get_write_perms (GtrPo * po);
-
      GList *gtr_po_get_messages (GtrPo * po);
 
-     void gtr_po_set_messages (GtrPo * po, GList * messages);
-
      GList *gtr_po_get_current_message (GtrPo * po);
 
      void gtr_po_update_current_message (GtrPo * po, GtrMsg * msg);
@@ -152,11 +148,6 @@ gtr_po_get_message_position (GtrPo * po);
 
      gchar *gtr_po_check_po_file (GtrPo * po);
 
-void
-gtr_po_emit_file_not_consistent (GtrPo * po);
-
-gboolean
-gtr_po_consistent_with_profile (GtrPo * po);
 /* Unexported funcs */
      void
        _gtr_po_increase_decrease_translated (GtrPo * po, gboolean increase);
