@@ -55,10 +55,11 @@ typedef struct
 
 struct _GtrProfileDialog
 {
-  GtkWindow parent_instance;
+  AdwDialog parent_instance;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrProfileDialog, gtr_profile_dialog, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrProfileDialog, gtr_profile_dialog,
+                            ADW_TYPE_DIALOG)
 
 enum
 {
@@ -79,7 +80,7 @@ static void
 on_cancel_button_clicked (GtkButton                  *button,
                           GtrProfileDialog           *dlg)
 {
-  gtk_window_destroy (GTK_WINDOW (dlg));
+  adw_dialog_close (ADW_DIALOG (dlg));
 }
 
 static void
@@ -116,11 +117,6 @@ gtr_profile_dialog_init (GtrProfileDialog *dlg)
 
   priv->editing = FALSE;
 
-  gtk_window_set_title (GTK_WINDOW (dlg), _("Translation Editor Profile"));
-  gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
-  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
-
   gtk_widget_init_template (GTK_WIDGET (dlg));
 
   g_signal_connect (GTK_BUTTON (priv->button_ok), "clicked",
@@ -172,8 +168,7 @@ fill_entries (GtrProfileDialog *dlg, GtrProfile *profile)
 }
 
 GtrProfileDialog *
-gtr_profile_dialog_new (GtkWidget  *parent,
-                        GtrProfile *profile)
+gtr_profile_dialog_new (GtrProfile *profile)
 {
   GtrProfileDialog *dlg;
 
@@ -184,11 +179,6 @@ gtr_profile_dialog_new (GtkWidget  *parent,
       fill_entries (dlg, profile);
     }
 
-  if (GTK_WINDOW (parent) != gtk_window_get_transient_for (GTK_WINDOW (dlg)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (parent));
-    }
-
   return dlg;
 }
 
