@@ -140,7 +140,6 @@ enum
 enum
 {
   PROP_0,
-  PROP_NAME,
   PROP_AUTOSAVE,
   PROP_AUTOSAVE_INTERVAL
 };
@@ -173,7 +172,7 @@ gtr_tab_focus_search_bar (GtrTab *tab)
 
   entry = gtr_search_bar_get_search (priv->gtr_search_bar);
 
-  gtk_entry_grab_focus_without_selecting (entry);
+  gtk_widget_grab_focus (GTK_WIDGET (entry));
 }
 
 void
@@ -946,15 +945,6 @@ gtr_tab_class_init (GtrTabClass * klass)
                   G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 
   /* Properties */
-  g_object_class_install_property (object_class,
-                                   PROP_NAME,
-                                   g_param_spec_string ("name",
-                                                        "Name",
-                                                        "The tab's name",
-                                                        NULL,
-                                                        G_PARAM_READABLE |
-                                                        G_PARAM_STATIC_STRINGS));
-
   g_object_class_install_property (object_class,
                                    PROP_AUTOSAVE,
                                    g_param_spec_boolean ("autosave",
@@ -1280,37 +1270,6 @@ gtr_tab_message_go_to (GtrTab * tab,
     }
 }
 
-/**
- * _gtr_tab_get_name:
- * @tab: a #GtrTab 
- * 
- * Return value: a new allocated string with the name of the @tab.
- */
-gchar *
-_gtr_tab_get_name (GtrTab *tab)
-{
-  GtrHeader *header;
-  GtrPoState state;
-  GtrTabPrivate *priv;
-  const gchar *str;
-  gchar *tab_name;
-
-  priv = gtr_tab_get_instance_private (tab);
-
-  header = gtr_po_get_header (priv->po);
-  state = gtr_po_get_state (priv->po);
-
-  str = gtr_header_get_prj_id_version (header);
-
-  if (state == GTR_PO_STATE_MODIFIED)
-    {
-      tab_name = g_strdup_printf ("*%s", str);
-      return tab_name;
-    }
-
-  return g_strdup (str);
-}
-
 gchar *
 _gtr_tab_get_tooltips (GtrTab *tab)
 {
